<?php

namespace Teknisa\MAN\Services;

use Teknisa\MAN\Utilities;

class TabelaPrecoAlteracaoAutomatica {
	
	
	protected $entityManager;

	public function __construct(\Doctrine\ORM\EntityManager $entityManager, $connection)  {
	    $this->connection    = $connection;
		$this->entityManager = $entityManager;
	}
	
	public function verificarProdutoExiste ($params) {
	    $result = $this->connection->fetchAll(self::SELECT_PRODUTO_TABELA,$params);
	    
	    if(sizeof($result) > 0) {
	        $result = true;
	    } else {
	        $result = false;
	    }
	    return $result;
	}
	
	public function recuperarPrecoDiferenciado ($params) {
	    $result = $this->connection->fetchAll(self::SELECT_PRECO_DIFERENCIADO,$params);
	    return $result;
	}
	
	public function updateInformacoesVigencia ($params) {
	    $this->entityManager->getConnection()->beginTransaction();
        try {
            
            $result = $this->connection->executeQuery(self::UPDATE_ITEMPRECO,$params);
            $this->entityManager->getConnection()->commit();
            
        } catch(Exception $e) {
            $this->entityManager->getConnection()->rollBack();
            throw $e->getMessage;
        }
	}
	
	public function insertInformacoesVigencia ($params) {
	    $this->entityManager->getConnection()->beginTransaction();
        try {
            
            $result = $this->connection->executeQuery(self::INSERT_ITEMPRECO,$params);
            $this->entityManager->getConnection()->commit();
            
        } catch(Exception $e) {
            $this->entityManager->getConnection()->rollBack();
            throw $e->getMessage;
        }
	}
	
	public function insertPrecoDiferenciado ($params) {
	    $this->entityManager->getConnection()->beginTransaction();
        try {
            $result = $this->connection->executeQuery(self::INSERT_PRECODIFERENCIADO,$params);
            $this->entityManager->getConnection()->commit();
            
        } catch(Exception $e) {
            $this->entityManager->getConnection()->rollBack();
            throw $e->getMessage;
        }
	}
	
	public function apagarPrecoDiferenciado ($params) {
	    $this->entityManager->getConnection()->beginTransaction();
        try {
            $result = $this->connection->executeQuery(self::DELETE_PRECODIFERENCIADO,$params);
            $this->entityManager->getConnection()->commit();
            
        } catch(Exception $e) {
            $this->entityManager->getConnection()->rollBack();
            throw $e->getMessage;
        }
	}
	
	
	const UPDATE_ITEMPRECO = "
        UPDATE ITEMPRECO SET
          VRPRECITEM   = :VRPRECITEM,
          VRCUSTITEM   = :VRCUSTITEM,
          VRPRESUGITEM = :VRPRESUGITEM,
          IDPRECVARIA  = :IDPRECVARIA,
          VRPRECITEMCL = :VRPRECITEMCL,
          IDPRODPROMOC = :IDPRODPROMOC,
          CDPRPAITABPR = :CDPRPAITABPR
        WHERE CDFILIAL     = :CDFILIAL 
          AND CDPRODUTO    = :CDPRODUTO
          AND CDTABEPREC   = :CDTABEPREC 
          AND DTINIVGPREC  = :DTINIVGPREC
          AND NRORG        = :NRORG";
          
    const INSERT_ITEMPRECO = "
        INSERT INTO ITEMPRECO (VRPRECITEM, VRCUSTITEM, VRPRESUGITEM, IDPRECVARIA, 
                                  VRPRECITEMCL, IDPRODPROMOC, CDPRPAITABPR, CDFILIAL,
                                  CDPRODUTO, CDTABEPREC, DTINIVGPREC, NRORG)
        VALUES (:VRPRECITEM, :VRCUSTITEM, :VRPRESUGITEM, :IDPRECVARIA, 
                :VRPRECITEMCL, :IDPRODPROMOC, :CDPRPAITABPR, :CDFILIAL,
                :CDPRODUTO, :CDTABEPREC, :DTINIVGPREC, :NRORG)";
	
	const SELECT_PRODUTO_TABELA = "
	    SELECT PR.CDPRODUTO
        FROM PRODUTO PR,
             ITEMPRECO IP,
          (SELECT COUNT(*) AS NRCOMPPROD,
                  CDPRODUTO,
                  NRORG
           FROM ROTFABRICA
           WHERE NRORG = :NRORG
           GROUP BY CDPRODUTO,
                    NRORG) R
        WHERE (PR.NRORG = :NRORG)
          AND (PR.CDPRODUTO = IP.CDPRODUTO)
          AND (PR.NRORG = IP.NRORG)
          AND (PR.CDPRODUTO = NVL(IP.CDPRPAITABPR, PR.CDPRODUTO))
          AND (IP.CDPRPAITABPR = PR.CDPRODUTO)
          AND (IP.CDFILIAL = :CDFILIAL)
          AND (IP.CDTABEPREC = :CDTABEPREC)
          AND (IP.DTINIVGPREC = :DTINIVGPREC)
          AND (PR.CDPRODUTO = :CDPRODUTO)
          AND (R.CDPRODUTO(+) = PR.CDPRODUTO)
          AND (R.NRORG(+) = PR.NRORG)
          AND (NVL(PR.IDPRODATIVPR, 'S') = 'S')
        ORDER BY PR.CDARVPROD";
	
	const SELECT_PRECO_DIFERENCIADO = "
	    SELECT I.CDFILIAL, HRINIPRECDIA, HRFINPRECDIA, NRDIASEMANPR, CDTABEPREC, DTINIVGPREC, CDPRODUTO,
	    CDPRPAITABPR, NRDIASEMANPR, HRINIPRECDIA, CDTIPOCONSPD, NRORG
        FROM ITEMPRECODIA I
        WHERE I.CDFILIAL = :CDFILIAL
          AND I.CDTABEPREC = :CDTABEPREC
          AND I.DTINIVGPREC = :DTINIVGPREC
          AND I.CDPRODUTO = :CDPRODUTO
          AND I.NRORG = :NRORG
        ORDER BY I.NRDIASEMANPR";
        
    const INSERT_PRECODIFERENCIADO = "
          INSERT INTO ITEMPRECODIA (VRPRECODIA, DTFINVALPREC, IDPERVALORPR, IDDESCACREPR, HRFINPRECDIA, IDVISUACUPOM,
                                    CDFILIAL, CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR, NRDIASEMANPR,
                                    HRINIPRECDIA, DTINIVALPREC, CDTIPOCONSPD, NRORG, NRORGULTATU)
          VALUES (:VRPRECODIA, :DTFINVALPREC, :IDPERVALORPR, :IDDESCACREPR, :HRFINPRECDIA, :IDVISUACUPOM,
                  :CDFILIAL, :CDTABEPREC, :DTINIVGPREC, :CDPRODUTO, :CDPRPAITABPR, :NRDIASEMANPR, :HRINIPRECDIA, :DTINIVALPREC,
                  :CDTIPOCONSPD, :NRORG, :NRORGULTATU)";
              
    const DELETE_PRECODIFERENCIADO = "
        DELETE FROM ITEMPRECODIA
        WHERE CDFILIAL = :CDFILIAL AND CDTABEPREC = :CDTABEPREC AND DTINIVGPREC = :DTINIVGPREC AND CDPRODUTO = :CDPRODUTO AND
        CDPRPAITABPR = :CDPRPAITABPR AND NRDIASEMANPR = :NRDIASEMANPR AND HRINIPRECDIA = :HRINIPRECDIA AND CDTIPOCONSPD = :CDTIPOCONSPD AND NRORG = :NRORG";
}